@@ -52,9 +52,6 @@ void smithfull3d(double *data, double *distVec, int *nSite,
     *dns = lpliksmith(data, mahalDist, jac, *nObs, *nSite);
   }
 
-  if (!R_FINITE(*dns))
-    *dns = MINF;
-  
   return;
 }
 
@@ -121,8 +118,5 @@ void smithdsgnmat3d(double *data, double *distVec, int *nSite, int *nObs,
     *dns -= penalization(shapepenmat, shapecoeff, *shapepenalty,
 			 *nshapecoeff, *npparshape);
 
-  if (!R_FINITE(*dns))
-    *dns = MINF;
-
   return;
 }
